@@ -19,6 +19,8 @@
 #---------------------------------------------------------------------------
 from base_module import ranaModule
 import marshal
+import os
+import modrana_utils
 
 def getModule(m,d,i):
   return(options(m,d,i))
@@ -28,11 +30,107 @@ class options(ranaModule):
   def __init__(self, m, d, i):
     ranaModule.__init__(self, m, d, i)
     self.options = {}
-    self.scroll = 0
+
+    # profile folder
+    self.profileFolderPath = self.modrana.getProfilePath()
+    # check the profile path and create the folders if necessary
+    modrana_utils.createFolderPath(self.profileFolderPath)
+
+    # load persistant options
     self.load()
     self.on = '<span color="green">ON</span>'
     self.off = '<span color="red">OFF</span>'
 
+  def getProfilePath(self):
+    """return path to the profile folder"""
+    # check if the path exists and create it if not
+    modrana_utils.createFolderPath(self.profileFolderPath)
+    return self.profileFolderPath
+
+  def getOptionsFilePath(self):
+    """return path to the options store filename"""
+    return os.path.join(self.getProfilePath(),"options.bin")
+
+  def getCacheFolderPath(self):
+    """return path to a folder used for various cache data"""
+    return self._assurePathFolder(self.getProfilePath(), "cache")
+
+  def getTracklogsFolderPath(self):
+    """return path to a folder for storing tracklogs"""
+    path = None
+    # first check if the user overrode the tracklog folder path
+    config = self.m.get('config', None)
+    if config:
+      path = config.getTracklogFolderPath()
+    if path == None:
+    # try to get the path from device module
+      if self.dmod:
+        path = self.dmod.getTracklogFolderPath()
+
+    if path == None: # this means there is no config or device path
+      # use default path & assure it exists
+      return self._assurePathFolder(self.getProfilePath(), "tracklogs")
+    else:
+      return self._assurePath(path)
+
+  def getMapFolderPath(self):
+    """return a path to folder for map data storage"""
+    path = None
+    # first check if the user overrode the map folder path
+    config = self.m.get('config', None)
+    if config:
+      path = config.getMapFolderPath()
+    if path == None:
+    # try to get the path from device module
+      if self.dmod:
+        path = self.dmod.getMapFolderPath()
+
+    if path == None: # this means there is no config or device path
+      # use default path & assure it exists
+      return self._assurePathFolder(self.getProfilePath(), "maps")
+    else:
+      return self._assurePath(path)
+
+  def getPOIFolderPath(self):
+    """return path to the POI folder"""
+    if self.dmod:
+      path = self.dmod.getPOIFolderPath()
+      if path != None: # None means there is no device dependent path
+        return self._assurePath(path)
+      else:
+        return self._assurePathFolder(self.getProfilePath(), "poi")
+    else:
+      return self._assurePathFolder(self.getProfilePath(), "poi")
+
+  def getPOIDatabasePath(self):
+    """return path to the POI database file"""
+    POIDBFilename = self.get('POIDBFilename', 'modrana_poi.db')
+    POIFolderPath = self.getPOIFolderPath()
+    return os.path.join(POIFolderPath,POIDBFilename)
+
+  def getLogFolderPath(self):
+    """return path to the POI folder"""
+    if self.dmod:
+      path = self.dmod.getLogFolderPath()
+      if path != None: # None means there is no device dependent path
+        return self._assurePath(path)
+      else:
+        return self._assurePathFolder(self.getProfilePath(), "debug_logs")
+    else:
+      return self._assurePathFolder(self.getProfilePath(), "debug_logs")
+  
+  def _assurePathFolder(self, path, folder):
+    """combine the given path and folder and make sure the path exists,
+    return the resulting path"""
+    path = os.path.join(path, folder)
+    return self._assurePath(path)
+
+  def _assurePath(self, path):
+    """assure path exists and return it back"""
+    # check if the path exists and create it if not
+    modrana_utils.createFolderPath(path)
+    return path
+
   def _getCategoryID(self, id):
     return "opt_cat_%s" % id # get a standardized id
 
@@ -122,7 +220,7 @@ class options(ranaModule):
     tiles = self.m.get("mapTiles", None)
     if(tiles):
       tileOptions = [("","None")]
-      layers = tiles.layers().items()
+      layers = self.modrana.getMapLayers().items()
       layers.sort()
       for name,layer in layers:
         tileOptions.append((name, layer.get('label',name)))
@@ -519,7 +617,7 @@ class options(ranaModule):
     # * network *
     group = addGroup("Network usage", "network_usage", catNetwork, "generic")
     addOpt("Network", "network",
-#      [("off","No use of network"),
+#      [("off","No use of network"), #TODO: implement this :)
       [("minimal", "Only for important data"),
        ("full", "Unlimited use of network")],
        group,
@@ -627,12 +725,24 @@ class options(ranaModule):
           if(not self.d.has_key(variable)):
             self.set(variable, default)
 
+  def _removeNonPersistent(self, inputDict):
+    """keys that begin with # are not saved
+    (as they mostly contain data that is either time sensitive or is
+    reloaded on startup)
+    ASSUMPTION: keys are strings of length>=1"""
+    try:
+      return dict((k, v) for k, v in inputDict.iteritems() if k[0] != '#')
+    except Exception, e:
+      print('options: error while filtering options\nsome nonpersistent keys might have been left in\nNOTE: keys should be strings of length>=1\n', e)
+      return self.d
 
   def save(self):
     print "options: saving options"
     try:
-      f = open(self.optionsFilename(), "w")
-      marshal.dump(self.d, f)
+      f = open(self.getOptionsFilePath(), "w")
+      # remove keys marked as nonpersistent
+      d = self._removeNonPersistent(self.d)
+      marshal.dump(d, f)
       f.close()
       print "options: successfully saved"
     except IOError:
@@ -640,7 +750,7 @@ class options(ranaModule):
 
   def load(self):
     try:
-      f = open(self.optionsFilename(), "r")
+      f = open(self.getOptionsFilePath(), "r")
       newData = marshal.load(f)
       f.close()
       if 'tileFolder' in newData: #TODO: do this more elegantly
@@ -664,9 +774,6 @@ class options(ranaModule):
     self.set('centred', True) # set centering to True at start to get setView to run
     self.set('editBatchMenuActive', False)
 
-      
-  def optionsFilename(self):
-    return("data/options.bin")
   
   def handleMessage(self, message, type, args):
     if type=="ml" and message=="scroll":
@@ -827,6 +934,19 @@ class options(ranaModule):
           # in corner: row number
           self.menuModule.showText(cr, "%d/%d" % (index+1, numItems), x4+0.85*w, y+3*border, w * 0.15 - border, 20)
 
+#  def checkProfilePath(self):
+#    """check if the profile folder exists, try to create it if not"""
+#    if os.path.exists(self.getProfilePath()):
+#      return True
+#    else:
+#      try:
+#        os.makedirs(self.profileFolderPath)
+#        print "creating profile folder in: %s" % self.profileFolderPath
+#        return True
+#      except Exception, e:
+#        print "options:Creating profile folder in path: %s failed:\n%s" % (self.profileFolderPath, e)
+#        return False
+
   def shutdown(self):
     """save the dictionary on exit"""
     self.save()
