@@ -19,8 +19,8 @@
 #---------------------------------------------------------------------------
 from base_module import ranaModule
 import gtk
-from upoints import gpx
 import time
+import os
 import geo
 
 
@@ -51,7 +51,7 @@ class tracklog(ranaModule):
     self.avgSpeed = None
     self.distance = None
     self.toolsMenuDone = False
-    self.category='log'
+    self.category='logs'
     self.traceColor = 'blue'
     self.traceIndex = 0
     self.pxpyIndex = []
@@ -179,6 +179,9 @@ class tracklog(ranaModule):
     self.currentLogName = name
 
     if type=='gpx':
+      """ importing the GPX module can be time consuming so import it
+      when it is really needed"""
+      from upoints import gpx
       self.currentLogGPX = gpx.Trackpoints()
       # set tracklog metadata
       self.currentLogGPX.name = name
@@ -189,7 +192,7 @@ class tracklog(ranaModule):
 
       filename = name + ".gpx"
       self.currentLogFileName = filename
-      self.currentLogPath = tracklogFolder + self.category + '/' + filename
+      self.currentLogPath = os.path.join(tracklogFolder, self.category, filename)
       self.saveGPXLog(self.currentLogGPX, self.currentLogFileName)
 
     self.lastTimestamp = self.lastSavedTimestamp = int(time.time())
@@ -216,7 +219,9 @@ class tracklog(ranaModule):
 
     """
 
-
+    """ importing the GPX module can be time consuming so import it
+    when it is really needed"""
+    from upoints import gpx
     newTrackpoints = map(lambda x: gpx.Trackpoint(x[0],x[1],None,None,x[2],x[3]), self.currentTempLog)
 
     if len(self.currentLogGPX)==0:
@@ -313,6 +318,9 @@ class tracklog(ranaModule):
 #    self.nodes = []
 #    file = open(filename, 'r')
 #    if(file):
+#      """ importing the GPX module can be time consuming so import it
+#      when it is really needed"""
+#      from upoints import gpx
 #      track = gpx.Trackpoints() # create new Trackpoints object
 #      track.import_locations(file) # load a gpx file into it
 #      for point in track[0]: #iterate over the points, track[0] is list of all points in file
