@@ -1,6 +1,7 @@
 # modRana - shared utility classes and methods
 from __future__ import with_statement # for python 2.5
 import threading
+import os
 try:
   import magic
   magicAvailable = True
@@ -116,4 +117,46 @@ def isTheStringAnImage(s):
     # lets hope it really is a tile
     return True
 
+def createFolderPath(newPath):
+  """
+  Creat a path for a directory and all needed parent forlders
+  -> parent directoryies will be created
+  -> if directory already exists, then do nothing
+  -> if there is another filsystem object (like a file) with the same name, raise an exception
+  """
+  if not newPath:
+    print("cannot create folder, wrong path: ", newPath)
+    return False
+  if os.path.isdir(newPath):
+    return True
+  elif os.path.isfile(newPath):
+    print("cannot create directory, file already exists: '%s'" % newPath)
+    return False
+  else:
+    print("creating path: %s" % newPath)
+    head, tail = os.path.split(newPath)
+    if head and not os.path.isdir(head):
+        createFolderPath(head) # NOTE: recursion
+    if tail:
+        os.mkdir(newPath)
+    return True
 
+# from:
+# http://www.5dollarwhitebox.org/drupal/node/84
+def bytes2PrettyUnitString(bytes):
+    bytes = float(bytes)
+    if bytes >= 1099511627776:
+        terabytes = bytes / 1099511627776
+        size = '%.2fTB' % terabytes
+    elif bytes >= 1073741824:
+        gigabytes = bytes / 1073741824
+        size = '%.2fGB' % gigabytes
+    elif bytes >= 1048576:
+        megabytes = bytes / 1048576
+        size = '%.2fMB' % megabytes
+    elif bytes >= 1024:
+        kilobytes = bytes / 1024
+        size = '%.2fKB' % kilobytes
+    else:
+        size = '%.2fb' % bytes
+    return size
\ No newline at end of file
